Client

Struct Client 

pub struct Client { /* private fields */ }
Available on crate feature io only.
MIDI client for sending and receiving MIDI messages

Implementations

Source

impl Client

pub async fn new(name: &str) -> Result<Self, Error>

Create a new midi client.

On macOS and iOS, CoreMIDI permanently routes hotplug notifications to whichever thread created the first MIDI client in the process. Create this client before anything else in the process uses CoreMIDI, or source_changes and destination_changes may never receive events.

pub async fn sources(&self) -> Result<Vec<Source>, Error>

Enumerate the available sources from the platform.

pub async fn destinations(&self) -> Result<Vec<Destination>, Error>

Enumerate the available destinations from the platform.

pub fn source_changes(&self) -> SourceChanges

Subscribe to a stream of source change events.

pub fn destination_changes(&self) -> DestinationChanges

Subscribe to a stream of destination change events.

pub async fn connect_source( &self, port: &Source, ) -> Result<SourceConnection, Error>

Connect to a known source. Use the sources method to query currently available sources.

pub async fn connect_destination( &self, port: &Destination, ) -> Result<DestinationConnection, Error>

Connect to a known destination. Use the destinations method to query currently available destinations.

pub async fn create_virtual_source( &self, name: &str, ) -> Result<VirtualSource, Error>

Creates a virtual source that can be used to send midi to destinations

pub async fn create_virtual_destination( &self, name: &str, ) -> Result<VirtualDestination, Error>

Creates a virtual destination that can be used to receive midi from sources